@@ -64,13 +64,17 @@ typedef enum icalerrorenum {
 icalerrorenum * icalerrno_return(void);
 #define icalerrno (*(icalerrno_return()))
 
+/*#cmakedefine LIBICAL_STATIC 1*/
+
 /** If true, libicl aborts after a call to icalerror_set_error
  *
  *  @warning NOT THREAD SAFE -- recommended that you do not change
  *           this in a multithreaded program.
  */
 #ifdef _MSC_VER
-  #ifdef BUILD_LIBICALDLL
+  #if defined(LIBICAL_STATIC)
+    #define LIBICAL_EXPORT extern
+  #elif defined(BUILD_LIBICALDLL)
     #define LIBICAL_EXPORT __declspec(dllexport)
   #else
     #define LIBICAL_EXPORT __declspec(dllimport)
@@ -121,7 +125,7 @@ if(icalerror_get_error_state(x)==ICAL_ERROR_FATAL || \
 void icalerror_set_errno(icalerrorenum x); 
 #endif
 
-#ifndef ICAL_ERRORS_ARE_FATAL
+#if !defined(ICAL_ERRORS_ARE_FATAL)
 #define ICAL_ERRORS_ARE_FATAL 0
 #endif
 
